<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://makewebbetter.com/
 * @since      1.0.0
 *
 * @package    Woocommerce_Wallet_System
 * @subpackage Woocommerce_Wallet_System/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Woocommerce_Wallet_System
 * @subpackage Woocommerce_Wallet_System/admin
 * @author     WP Swings <webmaster@wpswings.com>
 */
class Woocommerce_Wallet_System_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of this plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 * @param    string $hook      The plugin page slug.
	 */
	public function wws_admin_enqueue_styles( $hook ) {
		$screen = get_current_screen();

		if ( isset( $screen->id ) && 'wp-swings_page_wallet_system_for_woocommerce_menu' == $screen->id ) {

			wp_enqueue_style( 'mwb-wws-select2-css', WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'package/lib/select-2/woocommerce-wallet-system-select2.css', array(), time(), 'all' );

			wp_enqueue_style( 'mwb-wws-meterial-css', WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'package/lib/material-design/material-components-web.min.css', array(), time(), 'all' );
			wp_enqueue_style( 'mwb-wws-meterial-css2', WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'package/lib/material-design/material-components-v5.0-web.min.css', array(), time(), 'all' );
			wp_enqueue_style( 'mwb-wws-meterial-lite', WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'package/lib/material-design/material-lite.min.css', array(), time(), 'all' );

			wp_enqueue_style( 'mwb-wws-meterial-icons-css', WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'package/lib/material-design/icon.css', array(), time(), 'all' );

			wp_enqueue_style( $this->plugin_name . '-admin-globalse', WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'admin/src/scss/woocommerce-wallet-system-admin-global.css', array( 'mwb-wws-meterial-icons-css' ), time(), 'all' );

			wp_enqueue_style( $this->plugin_name, WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'admin/src/scss/woocommerce-wallet-system-admin.scss', array(), $this->version, 'all' );
			wp_enqueue_style( 'mwb-admin-min-css', WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'admin/css/mwb-admin.min.css', array(), $this->version, 'all' );
		}
		if ( isset( $screen->id ) && 'wp-swings_page_wallet_system_for_woocommerce_menu' == $screen->id ) {
			wp_enqueue_style( $this->plugin_name . '-admin-global', WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'admin/css/woocommerce-wallet-system-admin-extra.css', array(), time(), 'all' );
		}
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 * @param    string $hook      The plugin page slug.
	 */
	public function wws_admin_enqueue_scripts( $hook ) {

		$screen = get_current_screen();
		if ( isset( $screen->id ) && 'wp-swings_page_woocommerce_wallet_system_menu' === $screen->id || 'wp-swings_page_wallet_system_for_woocommerce_menu' === $screen->id ) {
			wp_enqueue_script( 'mwb-wws-select2', WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'package/lib/select-2/woocommerce-wallet-system-select2.js', array( 'jquery' ), time(), false );

			wp_enqueue_script( 'mwb-wws-metarial-js', WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'package/lib/material-design/material-components-web.min.js', array(), time(), false );
			wp_enqueue_script( 'mwb-wws-metarial-js2', WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'package/lib/material-design/material-components-v5.0-web.min.js', array(), time(), false );
			wp_enqueue_script( 'mwb-wws-metarial-lite', WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'package/lib/material-design/material-lite.min.js', array(), time(), false );

			wp_register_script( $this->plugin_name . 'admin-js', WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'admin/src/js/woocommerce-wallet-system-admin.js', array( 'jquery', 'mwb-wws-select2', 'mwb-wws-metarial-js', 'mwb-wws-metarial-js2', 'mwb-wws-metarial-lite' ), $this->version, false );

			wp_localize_script(
				$this->plugin_name . 'admin-js',
				'wws_admin_param',
				array(
					'ajaxurl'                       => admin_url( 'admin-ajax.php' ),
					'reloadurl'                     => admin_url( 'admin.php?page=woocommerce_wallet_system_menu' ),
					'wws_gen_tab_enable'            => get_option( 'wws_radio_switch_demo' ),
					'wws_ajax_error'                => __( 'An error occured!', 'woocommerce-wallet-system' ),
					'wws_license_field_error'       => __( 'Please enter license key.', 'woocommerce-wallet-system' ),
					'minimum_wallet_recharge_error' => __( 'Minimum wallet recharge amount should be less than maximum wallet recharge amount.', 'woocommerce-wallet-system' ),
					'wws_admin_param_location'      => ( admin_url( 'admin.php' ) . '?page=wallet_system_for_woocommerce_menu&wsfw_tab=wallet-system-for-woocommerce-general' ),
				)
			);

			wp_enqueue_script( $this->plugin_name . 'admin-js' );
		}
		if ( isset( $screen->id ) && 'wp-swings_page_wallet_system_for_woocommerce_menu' === $screen->id ) {
			wp_register_script( $this->plugin_name . 'admin-js', WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'admin/src/js/woocommerce-wallet-system-admin.js', array( 'jquery' ), $this->version, false );

			wp_localize_script(
				$this->plugin_name . 'admin-js',
				'wws_admin_param',
				array(
					'ajaxurl'                       => admin_url( 'admin-ajax.php' ),
					'reloadurl'                     => admin_url( 'admin.php?page=woocommerce_wallet_system_menu' ),
					'wws_gen_tab_enable'            => get_option( 'wws_radio_switch_demo' ),
					'wws_ajax_error'                => __( 'An error occured!', 'woocommerce-wallet-system' ),
					'wws_license_field_error'       => __( 'Please enter license key.', 'woocommerce-wallet-system' ),
					'minimum_wallet_recharge_error' => __( 'Minimum wallet recharge amount should be less than maximum wallet recharge amount.', 'woocommerce-wallet-system' ),
					'wws_admin_param_location'      => ( admin_url( 'admin.php' ) . '?page=wallet_system_for_woocommerce_menu&wsfw_tab=wallet-system-for-woocommerce-general' ),
					'datatable_pagination_text'     => __( 'Rows per page _MENU_', 'woocommerce-wallet-system' ),
					'datatable_info'                => __( '_START_ - _END_ of _TOTAL_', 'woocommerce-wallet-system' ),
					'datatable_excel'               => __( 'Export Excel', 'woocommerce-wallet-system' ),
					'datatable_csv'                 => __( 'Export CSV', 'woocommerce-wallet-system' ),
				)
			);

			wp_enqueue_script( $this->plugin_name . 'admin-js' );

			if ( ! empty( $_REQUEST['wsfw_tab'] ) ) {
				if ( 'wallet-system-wallet-transactions' === $_REQUEST['wsfw_tab'] || 'mwb-user-wallet-transactions' === $_REQUEST['wsfw_tab'] ) {
					wp_enqueue_script( 'mwb-wws-datetable-button', WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'package/lib/datatable/dataTables.buttons.js', array( 'mwb-admin-min-js' ), WOOCOMMERCE_WALLET_SYSTEM_VERSION, true );
					wp_enqueue_script( 'mwb-wws-datetable-zip', WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'package/lib/datatable/jszip.js', array( 'mwb-admin-min-js' ), WOOCOMMERCE_WALLET_SYSTEM_VERSION, true );
					wp_enqueue_script( 'mwb-wws-datetable-buttonhtml', WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'package/lib/datatable/buttons.html5.js', array( 'mwb-admin-min-js' ), WOOCOMMERCE_WALLET_SYSTEM_VERSION, true );
					wp_enqueue_script( 'mwb-wws-datetable-colvis', WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'package/lib/datatable/buttons.colVis.js', array( 'mwb-admin-min-js' ), WOOCOMMERCE_WALLET_SYSTEM_VERSION, true );
				}
			}
		}
	}

	/**
	 * Adding settings menu for WooCommerce Wallet System.
	 *
	 * @since    1.0.0
	 */
	public function wws_options_page() {
		global $submenu;
		if ( empty( $GLOBALS['admin_page_hooks']['mwb-plugins'] ) ) {
			add_menu_page( 'WP Swings', 'WP Swings', 'manage_options', 'mwb-plugins', array( $this, 'mwb_plugins_listing_page' ), WOOCOMMERCE_WALLET_SYSTEM_DIR_URL . 'admin/src/images/MWB_Grey-01.svg', 15 );
			$wws_menus = apply_filters( 'mwb_add_plugins_menus_array', array() );
			if ( is_array( $wws_menus ) && ! empty( $wws_menus ) ) {
				foreach ( $wws_menus as $wws_key => $wws_value ) {
					add_submenu_page( 'mwb-plugins', $wws_value['name'], $wws_value['name'], 'manage_options', $wws_value['menu_link'], array( $wws_value['instance'], $wws_value['function'] ) );
				}
			}
		}
	}

	/**
	 * Removing default submenu of parent menu in backend dashboard
	 *
	 * @since   1.0.0
	 */
	public function mwb_wws_remove_default_submenu() {
		global $submenu;
		if ( is_array( $submenu ) && array_key_exists( 'mwb-plugins', $submenu ) ) {
			if ( isset( $submenu['mwb-plugins'][0] ) ) {
				unset( $submenu['mwb-plugins'][0] );
			}
		}
	}


	/**
	 * WooCommerce Wallet System wws_admin_submenu_page.
	 *
	 * @since 1.0.0
	 * @param array $menus Marketplace menus.
	 */
	public function wws_admin_submenu_page( $menus = array() ) {
		$menus[] = array(
			'name'            => __( 'WooCommerce Wallet System', 'woocommerce-wallet-system' ),
			'slug'            => 'woocommerce_wallet_system_menu',
			'menu_link'       => 'woocommerce_wallet_system_menu',
			'instance'        => $this,
			'function'        => 'wws_options_menu_html',
		);
		return $menus;
	}


	/**
	 * WooCommerce Wallet System mwb_plugins_listing_page.
	 *
	 * @since 1.0.0
	 */
	public function mwb_plugins_listing_page() {
		$active_marketplaces = apply_filters( 'mwb_add_plugins_menus_array', array() );
		if ( is_array( $active_marketplaces ) && ! empty( $active_marketplaces ) ) {
			require WOOCOMMERCE_WALLET_SYSTEM_DIR_PATH . 'admin/partials/welcome.php';
		}
	}

	/**
	 * WooCommerce Wallet System admin menu page.
	 *
	 * @since    1.0.0
	 */
	public function wws_options_menu_html() {

		include_once WOOCOMMERCE_WALLET_SYSTEM_DIR_PATH . 'admin/partials/woocommerce-wallet-system-admin-dashboard.php';
	}


	/**
	 * WooCommerce Wallet System admin menu page.
	 *
	 * @since    1.0.0
	 * @param array $wws_settings_general Settings fields.
	 */
	public function wws_admin_general_settings_page( $wws_settings_general ) {
		if ( is_array( $wws_settings_general ) && ! empty( $wws_settings_general ) ) {
			$wws_settings_general[] = array(
				'title'       => __( 'Minimum Wallet Recharge Amount ( ', 'woocommerce-wallet-system' ) . get_woocommerce_currency_symbol() . ' )',
				'type'        => 'number',
				'description' => __( 'Minimum amount needed to recharge wallet.', 'woocommerce-wallet-system' ),
				'name'        => 'wws_min_wallet_recharge_amount',
				'id'          => 'wws_min_wallet_recharge_amount',
				'value'       => get_option( 'wws_min_wallet_recharge_amount', '' ),
				'class'       => 'wpg-number-class',
			);
			$wws_settings_general[] = array(
				'title'       => __( 'Maximum Wallet Recharge Amount ( ', 'woocommerce-wallet-system' ) . get_woocommerce_currency_symbol() . ' )',
				'type'        => 'number',
				'description' => __( 'Maximum amount for wallet recharge.', 'woocommerce-wallet-system' ),
				'name'        => 'wws_max_wallet_recharge_amount',
				'id'          => 'wws_max_wallet_recharge_amount',
				'value'       => get_option( 'wws_max_wallet_recharge_amount', '' ),
				'class'       => 'wpg-number-class',
			);
			$wws_settings_general[] = array(
				'title'       => __( 'Message For Customer', 'woocommerce-wallet-system' ),
				'type'        => 'text',
				'description' => __( 'Enter message for customer at the time of withdrawal request', 'woocommerce-wallet-system' ),
				'name'        => 'wws_withdrawal_page_message',
				'id'          => 'wws_withdrawal_page_message',
				'value'       => get_option( 'wws_withdrawal_page_message' ),
				'placeholder' => __( 'message', 'woocommerce-wallet-system' ),
				'class'       => 'wws-text-class',
			);
		}
		return $wws_settings_general;
	}

	/**
	 * WooCommerce Wallet System admin menu page.
	 *
	 * @since    1.0.0
	 * @param array $wws_settings_template Settings fields.
	 */
	public function wws_admin_template_settings_page( $wws_settings_template ) {
		$wws_settings_template = array(
			array(
				'title' => __( 'Text Field Demo', 'woocommerce-wallet-system' ),
				'type'  => 'text',
				'description'  => __( 'This is text field demo follow same structure for further use.', 'woocommerce-wallet-system' ),
				'id'    => 'wws_text_demo',
				'value' => '',
				'class' => 'wws-text-class',
				'placeholder' => __( 'Text Demo', 'woocommerce-wallet-system' ),
			),
			array(
				'title' => __( 'Number Field Demo', 'woocommerce-wallet-system' ),
				'type'  => 'number',
				'description'  => __( 'This is number field demo follow same structure for further use.', 'woocommerce-wallet-system' ),
				'id'    => 'wws_number_demo',
				'value' => '',
				'class' => 'wws-number-class',
				'placeholder' => '',
			),
			array(
				'title' => __( 'Password Field Demo', 'woocommerce-wallet-system' ),
				'type'  => 'password',
				'description'  => __( 'This is password field demo follow same structure for further use.', 'woocommerce-wallet-system' ),
				'id'    => 'wws_password_demo',
				'value' => '',
				'class' => 'wws-password-class',
				'placeholder' => '',
			),
			array(
				'title' => __( 'Textarea Field Demo', 'woocommerce-wallet-system' ),
				'type'  => 'textarea',
				'description'  => __( 'This is textarea field demo follow same structure for further use.', 'woocommerce-wallet-system' ),
				'id'    => 'wws_textarea_demo',
				'value' => '',
				'class' => 'wws-textarea-class',
				'rows' => '5',
				'cols' => '10',
				'placeholder' => __( 'Textarea Demo', 'woocommerce-wallet-system' ),
			),
			array(
				'title' => __( 'Select Field Demo', 'woocommerce-wallet-system' ),
				'type'  => 'select',
				'description'  => __( 'This is select field demo follow same structure for further use.', 'woocommerce-wallet-system' ),
				'id'    => 'wws_select_demo',
				'value' => '',
				'class' => 'wws-select-class',
				'placeholder' => __( 'Select Demo', 'woocommerce-wallet-system' ),
				'options' => array(
					'' => __( 'Select option', 'woocommerce-wallet-system' ),
					'INR' => __( 'Rs.', 'woocommerce-wallet-system' ),
					'USD' => __( '$', 'woocommerce-wallet-system' ),
				),
			),
			array(
				'title' => __( 'Multiselect Field Demo', 'woocommerce-wallet-system' ),
				'type'  => 'multiselect',
				'description'  => __( 'This is multiselect field demo follow same structure for further use.', 'woocommerce-wallet-system' ),
				'id'    => 'wws_multiselect_demo',
				'value' => '',
				'class' => 'wws-multiselect-class mwb-defaut-multiselect',
				'placeholder' => '',
				'options' => array(
					'default' => __( 'Select currency code from options', 'woocommerce-wallet-system' ),
					'INR' => __( 'Rs.', 'woocommerce-wallet-system' ),
					'USD' => __( '$', 'woocommerce-wallet-system' ),
				),
			),
			array(
				'title' => __( 'Checkbox Field Demo', 'woocommerce-wallet-system' ),
				'type'  => 'checkbox',
				'description'  => __( 'This is checkbox field demo follow same structure for further use.', 'woocommerce-wallet-system' ),
				'id'    => 'wws_checkbox_demo',
				'value' => '',
				'class' => 'wws-checkbox-class',
				'placeholder' => __( 'Checkbox Demo', 'woocommerce-wallet-system' ),
			),

			array(
				'title' => __( 'Radio Field Demo', 'woocommerce-wallet-system' ),
				'type'  => 'radio',
				'description'  => __( 'This is radio field demo follow same structure for further use.', 'woocommerce-wallet-system' ),
				'id'    => 'wws_radio_demo',
				'value' => '',
				'class' => 'wws-radio-class',
				'placeholder' => __( 'Radio Demo', 'woocommerce-wallet-system' ),
				'options' => array(
					'yes' => __( 'YES', 'woocommerce-wallet-system' ),
					'no' => __( 'NO', 'woocommerce-wallet-system' ),
				),
			),
			array(
				'title' => __( 'Enable', 'woocommerce-wallet-system' ),
				'type'  => 'radio-switch',
				'description'  => __( 'This is switch field demo follow same structure for further use.', 'woocommerce-wallet-system' ),
				'id'    => 'wws_radio_switch_demo',
				'value' => '',
				'class' => 'wws-radio-switch-class',
				'options' => array(
					'yes' => __( 'YES', 'woocommerce-wallet-system' ),
					'no' => __( 'NO', 'woocommerce-wallet-system' ),
				),
			),

			array(
				'type'  => 'button',
				'id'    => 'wws_button_demo',
				'button_text' => __( 'Button Demo', 'woocommerce-wallet-system' ),
				'class' => 'wws-button-class',
			),
		);
		return $wws_settings_template;
	}

	/**
	 * Check whether order has user id as meta key
	 *
	 * @param int $user_id user id.
	 * @param int $order_id order id.
	 * @return int
	 */
	public function wws_check_order_meta_for_userid( $user_id, $order_id ) {
		$wallet_userid = get_post_meta( $order_id, 'mwb_wws_user_id', true );
		return $wallet_userid;
	}

	/**
	 * Check whether order has recharge_reason as meta key
	 *
	 * @param string $recharge_reason reason for recharge.
	 * @param int    $order_id order id.
	 * @return string
	 */
	public function wws_check_order_meta_for_recharge_reason( $recharge_reason = '', $order_id ) {
		$recharge_reason = get_post_meta( $order_id, 'mwb_wws_recharge_reason', true );
		return $recharge_reason;
	}

	/**
	 * Check license key is valid or not.
	 *
	 * @return void
	 */
	public function mwb_wws_check_license() {
		$license_key = get_option( 'mwb_wws_lic_key', false );
		$api_params = array(
			'slm_action'         => 'slm_check',
			'secret_key'         => WOOCOMMERCE_WALLET_SYSTEM_SPECIAL_SECRET_KEY,
			'license_key'        => $license_key,
			'_registered_domain' => $_SERVER['SERVER_NAME'],
			'item_reference'     => urlencode( WOOCOMMERCE_WALLET_SYSTEM_ITEM_REFERENCE ),
			'product_reference'  => 'MWBPK-56844',
		);

		$query = esc_url_raw( add_query_arg( $api_params, WOOCOMMERCE_WALLET_SYSTEM_LICENSE_SERVER_URL ) );

		$ch = curl_init();
		curl_setopt( $ch, CURLOPT_URL, $query );
		curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
		curl_setopt( $ch, CURLOPT_TIMEOUT, 20 );
		curl_setopt( $ch, CURLOPT_SSL_VERIFYSTATUS, false );

		$response = curl_exec( $ch );

		if ( is_wp_error( $response ) ) {
			return;
		} else {
			$license_data = json_decode( $response );

			if ( isset( $license_data->result ) && 'success' === $license_data->result && isset( $license_data->status ) && 'active' === $license_data->status ) {
				if ( ! function_exists( 'is_plugin_active_for_network' ) ) {
					require_once ABSPATH . '/wp-admin/includes/plugin.php';
				}
				if ( is_plugin_active_for_network( 'woocommerce-wallet-system/woocommerce-wallet-system.php' ) || is_multisite() ) {
					global $wpdb;
					foreach ( $wpdb->get_col( "SELECT blog_id FROM $wpdb->blogs" ) as $blog_id ) {
						switch_to_blog( $blog_id );
						update_option( 'mwb_wws_pro_valid_license', true );
						restore_current_blog();
					}
				} else {
					update_option( 'mwb_wws_pro_valid_license', true );
				}
			} else {
				if ( ! function_exists( 'is_plugin_active_for_network' ) ) {
					require_once ABSPATH . '/wp-admin/includes/plugin.php';
				}
				if ( is_plugin_active_for_network( 'woocommerce-wallet-system/woocommerce-wallet-system.php' ) || is_multisite() ) {
					global $wpdb;
					foreach ( $wpdb->get_col( "SELECT blog_id FROM $wpdb->blogs" ) as $blog_id ) {
						switch_to_blog( $blog_id );
						delete_option( 'mwb_wws_pro_valid_license' );
						restore_current_blog();
					}
				} else {
					delete_option( 'mwb_wws_pro_valid_license' );
				}
			}
		}

	}

	/**
	 * Show message if license is not activated.
	 *
	 * @return void
	 */
	public function mwb_wws_show_additional_section() {
		$callname_lic         = Woocommerce_Wallet_System::$lic_callback_function;
		$callname_lic_initial = Woocommerce_Wallet_System::$lic_ini_callback_function;
		$day_count            = Woocommerce_Wallet_System::$callname_lic_initial();
		if ( $day_count > 0 ) {
			if ( ! get_option( 'mwb_wws_pro_valid_license', 0 ) ) {
				$day_count_warning = floor( $day_count );
				$day_string = sprintf( _n( '%s day', '%s days', $day_count_warning, 'woocommerce-wallet-system' ), number_format_i18n( $day_count_warning ) );
				$day_string = '<span id="mwb-wsfw-day-count" >' . $day_string . '</span>';
				?>
				<div class="thirty-days-notice mwb-header-container mwb-bg-white mwb-r-8">
					<h1 class="mwb-header-title">
						<p>
							<strong><a href="?page=wallet_system_for_woocommerce_menu&wsfw_tab=woocommerce-wallet-system-license"><?php esc_html_e( 'Activate', 'woocommerce-wallet-system' ); ?></a><?php printf( __( ' the license key before %s or you may risk losing data and the WooCommerce Wallet System plugin will also become dysfunctional.', 'woocommerce-wallet-system' ), $day_string ); ?></strong>
						</p>
					</h1>
				</div>
				<?php
			}
		} else {
			if ( ! get_option( 'mwb_wws_pro_valid_license', 0 ) ) {
				?>
		<div class="thirty-days-notice mwb-header-container mwb-bg-white mwb-r-8">
			<h1 class="mwb-header-title">
				<p>
					<strong><?php esc_html_e( ' Your trial period is over please activate license to use the WooCommerce Wallet System features.', 'woocommerce-wallet-system' ); ?></strong>
				</p>
			</h1>
		</div>
				<?php
			}
		}
	}

	/**
	 * Add license tab in plugin setting.
	 *
	 * @param array $default_tabs default setting tabs.
	 * @return array
	 */
	public function mwb_wws_plug_extra_tabs( $default_tabs ) {
		$new_tabs = array();
		if ( is_array( $default_tabs ) && ! empty( $default_tabs ) ) {
			foreach ( $default_tabs as $tab => $default_tab ) {
				if ( 'wallet-system-rest-api' === $tab ) {
					if ( ! get_option( 'mwb_wws_pro_valid_license', 0 ) ) {
						$new_tabs['woocommerce-wallet-system-license'] = array(
							'title'     => esc_html__( 'Activate License', 'woocommerce-wallet-system' ),
							'name'      => 'woocommerce-wallet-system-license',
							'file_path' => WOOCOMMERCE_WALLET_SYSTEM_DIR_PATH . 'admin/partials/woocommerce-wallet-system-license.php',
						);
					}
				}
				$new_tabs[ $tab ] = $default_tab;
			}
		}
		return $new_tabs;
	}

	/**
	 * Return path for license page.
	 *
	 * @param string $path path of license page.
	 * @return string
	 */
	public function mwb_wws_template_path( $path ) {
		if ( defined( 'WALLET_SYSTEM_FOR_WOOCOMMERCE_VERSION' ) ) {
			if ( WALLET_SYSTEM_FOR_WOOCOMMERCE_DIR_PATH . 'admin/partials/woocommerce-wallet-system-license.php' === $path ) {
				$path = WOOCOMMERCE_WALLET_SYSTEM_DIR_PATH . 'admin/partials/woocommerce-wallet-system-license.php';
			}
		}
		return $path;
	}

	/**
	 * Include pro overview content
	 *
	 * @return void
	 */
	public function mwb_wws_include_overview() {
		include_once WOOCOMMERCE_WALLET_SYSTEM_DIR_PATH . 'admin/partials/woocommerce-wallet-system-overview.php';
	}

	/**
	 * Convert the orders amount into base currency amount.
	 *
	 * @param string $price price.
	 * @param string $currency currency.
	 * @return string
	 */
	public function mwb_wws_update_wallet_to_base_price( $price, $currency ) {
		if ( function_exists( 'mwb_mmcsfw_admin_fetch_currency_rates_to_base_currency' ) ) {
			$base_amount = mwb_mmcsfw_admin_fetch_currency_rates_to_base_currency( $currency, $price );
			return $base_amount;
		} else {
			return $price;
		}
	}

	/**
	 * Saving the wallet page id on plugin updation.
	 *
	 * @return void
	 */
	public function mwb_wws_save_wallet_page_id() {

		$wallet_page_id = get_option( 'mwb_wws_wallet_top_page_id' );
		$wallet_page    = get_post( $wallet_page_id );
		if ( empty( $wallet_page ) ) {
			$page = get_page_by_title( 'My Wallet' );
			if ( ! empty( $page ) ) {
				update_option( 'mwb_wws_wallet_top_page_id', $page->ID );
				update_option( 'mwb_wws_saved_wallet_page_id', 'true' );
			}
		}

	}

}
