<?php
/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://makewebbetter.com/
 * @since      1.0.0
 *
 * @package    Woocommerce_Wallet_System
 * @subpackage Woocommerce_Wallet_System/admin/partials
 */

if ( ! defined( 'ABSPATH' ) ) {

	exit(); // Exit if accessed directly.
}

global $wws_mwb_wws_obj;
$wws_active_tab   = isset( $_GET['wws_tab'] ) ? sanitize_key( $_GET['wws_tab'] ) : 'woocommerce-wallet-system-general';
$wws_default_tabs = $wws_mwb_wws_obj->mwb_wws_plug_default_tabs();
?>
<header>
	<div class="mwb-header-container mwb-bg-white mwb-r-8">
		<h1 class="mwb-header-title"><?php echo esc_attr( strtoupper( str_replace( '-', ' ', $wws_mwb_wws_obj->wws_get_plugin_name() ) ) ); ?></h1>
		<a href="https://docs.wpswings.com/wallet-system-for-woocommerce-pro/?utm_source=wpswings-wallet-doc&utm_medium=wallet-pro-backend&utm_campaign=doc" target="_blank" class="mwb-link"><?php esc_html_e( 'Documentation', 'woocommerce-wallet-system' ); ?></a>
		<span>|</span>
		<a href="https://wpswings.com/contact-us/" target="_blank" class="mwb-link"><?php esc_html_e( 'Support', 'woocommerce-wallet-system' ); ?></a>
	</div>
</header>

<main class="mwb-main mwb-bg-white mwb-r-8">
	<nav class="mwb-navbar">
		<ul class="mwb-navbar__items">
			<?php
			if ( is_array( $wws_default_tabs ) && ! empty( $wws_default_tabs ) ) {

				foreach ( $wws_default_tabs as $wws_tab_key => $wws_default_tabs ) {

					$wws_tab_classes = 'mwb-link ';

					if ( ! empty( $wws_active_tab ) && $wws_active_tab === $wws_tab_key ) {
						$wws_tab_classes .= 'active';
					}
					?>
					<li>
						<a id="<?php echo esc_attr( $wws_tab_key ); ?>" href="<?php echo esc_url( admin_url( 'admin.php?page=woocommerce_wallet_system_menu' ) . '&wws_tab=' . esc_attr( $wws_tab_key ) ); ?>" class="<?php echo esc_attr( $wws_tab_classes ); ?>"><?php echo esc_html( $wws_default_tabs['title'] ); ?></a>
					</li>
					<?php
				}
			}
			?>
		</ul>
	</nav>

	<section class="mwb-section">
		<div>
			<?php
			do_action( 'mwb_wws_before_general_settings_form' );
			// if submenu is directly clicked on woocommerce.
			if ( empty( $wws_active_tab ) ) {
				$wws_active_tab = 'mwb_wws_plug_general';
			}

			// look for the path based on the tab id in the admin templates.
			$wws_tab_content_path = 'admin/partials/' . $wws_active_tab . '.php';

			$wws_mwb_wws_obj->mwb_wws_plug_load_template( $wws_tab_content_path );

			do_action( 'mwb_wws_after_general_settings_form' );
			?>
		</div>
	</section>
