(function( $ ) {
	'use strict';

	/**
	 * All of the code for your admin-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */

	$(document).ready(function() {

		const MDCText = mdc.textField.MDCTextField;
        const textField = [].map.call(document.querySelectorAll('.mdc-text-field'), function(el) {
            return new MDCText(el);
        });
        const MDCRipple = mdc.ripple.MDCRipple;
        const buttonRipple = [].map.call(document.querySelectorAll('.mdc-button'), function(el) {
            return new MDCRipple(el);
        });
        const MDCSwitch = mdc.switchControl.MDCSwitch;
        const switchControl = [].map.call(document.querySelectorAll('.mdc-switch'), function(el) {
            return new MDCSwitch(el);
        });

        $('.mwb-password-hidden').click(function() {
            if ($('.mwb-form__password').attr('type') == 'text') {
                $('.mwb-form__password').attr('type', 'password');
            } else {
                $('.mwb-form__password').attr('type', 'text');
            }
        });
		$('#wws_min_wallet_recharge_amount').blur(function() {
			var min_amount = $(this).val();
			min_amount = parseInt(min_amount);
			var max_amount = $('#wws_max_wallet_recharge_amount').val();
			max_amount = parseInt(max_amount);
            if ( min_amount > max_amount ) {
				if ($('.error').length === 0) {
					$('#wws_min_wallet_recharge_amount').parent().after('<p class="error">' + wws_admin_param.minimum_wallet_recharge_error + '</p>');
					$('#wsfw_button_demo').prop('disabled', true);
				}
            } else {
                $('.error').remove();
				$('#wsfw_button_demo').prop('disabled', false);
            }
        });
		$('#wws_max_wallet_recharge_amount').blur(function() {
			var max_amount = $(this).val();
			var min_amount = $('#wws_min_wallet_recharge_amount').val();
			min_amount = parseInt(min_amount);
			max_amount = parseInt(max_amount);
            if ( min_amount > max_amount ) {
				if ($('.error').length === 0) {
					$('#wws_min_wallet_recharge_amount').parent().after('<p class="error">' + wws_admin_param.minimum_wallet_recharge_error + '</p>');
					$('#wsfw_button_demo').prop('disabled', true);
				}
            } else {
				$('.error').remove();
				$('#wsfw_button_demo').prop('disabled', false);
            }
        });

		jQuery('#mwb-wpg-gen-table').dataTable().fnDestroy();
		jQuery('#mwb-wpg-gen-table').DataTable({
			"dom": 'B<"">tr<"bottom"lip>', //extentions position
			"ordering": true,
			buttons: [
				{
					extend: 'excel',
					title: '',
					text: wws_admin_param.datatable_excel,
					exportOptions: {
						columns: [ 0, 1, 2, 3, 4, 5, 6, 7, 8 ]
					}
				},
				{
					extend: 'csv',
					text: wws_admin_param.datatable_csv,
					exportOptions: {
						columns: [ 0, 1, 2, 3, 4, 5, 6, 7, 8 ]
					}
				}
			],
			language: {
				"lengthMenu": wws_admin_param.datatable_pagination_text,
				"info": wws_admin_param.datatable_info,
	
				paginate: {
					next: '<svg width="8" height="12" viewBox="0 0 8 12" fill="none" xmlns="http://www.w3.org/2000/svg"><path fill-rule="evenodd" clip-rule="evenodd" d="M1.99984 0L0.589844 1.41L5.16984 6L0.589844 10.59L1.99984 12L7.99984 6L1.99984 0Z" fill="#8E908F"/></svg>',
					previous: '<svg width="8" height="12" viewBox="0 0 8 12" fill="none" xmlns="http://www.w3.org/2000/svg"><path fill-rule="evenodd" clip-rule="evenodd" d="M6.00016 12L7.41016 10.59L2.83016 6L7.41016 1.41L6.00016 -1.23266e-07L0.000156927 6L6.00016 12Z" fill="#8E908F"/></svg>'
				}
			}
		});

		jQuery('.mwb-wpg-user-transaction-table').dataTable().fnDestroy();
		jQuery('.mwb-wpg-user-transaction-table').DataTable({
			"dom": 'B<"">tr<"bottom"lip>',
			"ordering": true,
			buttons: [
				{
					extend: 'excel',
					title: '',
					text: wws_admin_param.datatable_excel,
					exportOptions: {
						columns: [ 0, 1, 2, 3, 4, 5 ]
					}
				},
				{
					extend: 'csv',
					text: wws_admin_param.datatable_csv,
					exportOptions: {
						columns: [ 0, 1, 2, 3, 4, 5 ]
					}
				}
			],
			language: {
				"lengthMenu": wws_admin_param.datatable_pagination_text,
				"info": wws_admin_param.datatable_info,
	
				paginate: {
					next: '<svg width="8" height="12" viewBox="0 0 8 12" fill="none" xmlns="http://www.w3.org/2000/svg"><path fill-rule="evenodd" clip-rule="evenodd" d="M1.99984 0L0.589844 1.41L5.16984 6L0.589844 10.59L1.99984 12L7.99984 6L1.99984 0Z" fill="#8E908F"/></svg>',
					previous: '<svg width="8" height="12" viewBox="0 0 8 12" fill="none" xmlns="http://www.w3.org/2000/svg"><path fill-rule="evenodd" clip-rule="evenodd" d="M6.00016 12L7.41016 10.59L2.83016 6L7.41016 1.41L6.00016 -1.23266e-07L0.000156927 6L6.00016 12Z" fill="#8E908F"/></svg>'
				}
			}
		});
	
	});

	
	$(window).load(function(){
		// add select2 for multiselect.
		if( $(document).find('.mwb-defaut-multiselect').length > 0 ) {
			$(document).find('.mwb-defaut-multiselect').select2();
		}
	});

	$(document).on( 'blur','#license_key', function(){
		var license_key = $(this).val();
		if ( license_key == '' ) {
			$("#mwb_wws_license_activation_status").css("color", "#ff3333");
			jQuery("#mwb_wws_license_activation_status").html(wws_admin_param.wws_license_field_error);
			$('#activate_license').prop('disabled', true);
		} else {
			jQuery("#mwb_wws_license_activation_status").html('');
			$('#activate_license').prop('disabled', false);	
		}
	});
	
	// on clicking license activation button
	$(document).on('submit', '#mwb_wws_license_form', function(e){
		e.preventDefault();
		var license_key = $('#license_key').val();
		if ( license_key == '' ) {
			$("#mwb_wws_license_activation_status").css("color", "#ff3333");
			jQuery("#mwb_wws_license_activation_status").html(wws_admin_param.wws_license_field_error);
		} else {	
			mwb_wws_send_license_request(license_key);
		}
		
	});


	function mwb_wws_send_license_request(license_key) {
		$.ajax({
		   type: "POST",
		   dataType: "JSON",
		   url: wws_admin_param.ajaxurl,
			data: {
				action: "mwb_wws_validate_license_key",
				license_key: license_key,
			},
	
			success: function(data) {
				if (data.status == true) {
					$("#mwb_wws_license_activation_status").css("color", "#42b72a");
			
					jQuery("#mwb_wws_license_activation_status").html(data.msg);
			
					location = wws_admin_param.wws_admin_param_location;
				} else {
					$("#mwb_wws_license_activation_status").css("color", "#ff3333");
			
					jQuery("#mwb_wws_license_activation_status").html(data.msg);
			
					jQuery("#license_key").val("");
				}
			},
		})
		.fail(function ( response ) {
			$("#mwb_wws_license_activation_status").css("color", "#ff3333");
			jQuery("#mwb_wws_license_activation_status").html(wws_admin_param.wws_ajax_error);
		});
	}
	
})( jQuery );
