<?php
/**
 * Handles all admin ajax requests.
 *
 * @link       https://makewebbetter.com/
 * @since      1.0.0
 *
 * @package    Woocommerce_Wallet_System
 * @subpackage Woocommerce_Wallet_System/includes
 */

/**
 * Handles all admin ajax requests.
 *
 * All the functions required for handling admin ajax requests
 * required by the plugin.
 *
 * @since      1.0.0
 * @package    Woocommerce_Wallet_System
 * @subpackage Woocommerce_Wallet_System/includes
 * @author     WP Swings <webmaster@wpswings.com>
 */
class Wallet_System_AjaxHandler1 {

	/**
	 * Construct.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		add_action( 'wp_ajax_mwb_generate_qr_code', array( &$this, 'mwb_generate_qr_code' ) );
	}

	/**
	 * Generates qr code image.
	 *
	 * @return void
	 */
	public function mwb_generate_qr_code() {
		if ( is_user_logged_in() ) {
			$generate = true;
			$message = array();

			$unique_code = rand();
			require_once plugin_dir_path( dirname( __FILE__ ) ) . 'WalletQrcode/qrlib.php';
			$upload_dir  = wp_upload_dir();
			$upload_url  = $upload_dir['subdir'] . '/wallet-qr-' . $unique_code . '.png';
			$upload_path = $upload_dir['path'] . '/wallet-qr-' . $unique_code . '.png';

			$account_url = get_permalink( get_option( 'woocommerce_myaccount_page_id' ) );
			$wallet_topup_link = wc_get_endpoint_url( 'mwb-wallet-topup', $unique_code );
			$wallet_topup_link1 = $account_url . $wallet_topup_link;

			$link = home_url( 'my-account/mwb-wallet/wallet-topup/wallet_id=' . $unique_code );
			// Generates QR Code and Stores it in directory given.
			QRcode::png( $wallet_topup_link1, $upload_path );
			$user_id = get_current_user_id();
			$wallet_qr_code = update_user_meta( $user_id, 'wallet_qr_code_image', $upload_url );
			if ( $wallet_qr_code ) {
				$message['message'] = $link;
				$message['type']    = $wallet_topup_link1;
			} else {
				$message['message'] = esc_html__( 'image is not saved', 'woocommerce-wallet-system' );
				$message['type']    = esc_html__( 'woocommerce-error', 'woocommerce-wallet-system' );
			}
			wp_send_json( $message );
		}
	}


}
