<?php
/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://makewebbetter.com/
 * @since      1.0.0
 *
 * @package    Woocommerce_Wallet_System
 * @subpackage Woocommerce_Wallet_System/public/partials
 */

$user_id = get_current_user_id();

global $wp;


if ( isset( $_POST['mwb_generate_qr_code'] ) && ! empty( $_POST['mwb_generate_qr_code'] ) ) {

	unset( $_POST['mwb_generate_qr_code'] );

	if ( is_user_logged_in() ) {
		$generate = true;
		$message = array();

		$unique_code = rand();
		require_once plugin_dir_path( dirname( __FILE__ ) ) . '../WalletQrcode/qrlib.php';
		$wallet_page_id = get_option( 'mwb_wws_wallet_top_page_id' );
		$page_url       = get_permalink( $wallet_page_id );
		if ( get_option( 'permalink_structure' ) ) {
			if ( substr( $page_url, -1 ) == '/' ) {
				$wallet_topup_link = $page_url . 'mwb-wallet-topup/' . $unique_code . '/';
			} else {
				$wallet_topup_link = $page_url . '/mwb-wallet-topup/' . $unique_code;
			}
		} else {
			$wallet_topup_link = add_query_arg( 'mwb-wallet-topup', $unique_code, $page_url );
		}
		$upload_dir        = wp_upload_dir();
		$upload_url        = $upload_dir['subdir'] . '/wallet-qr-' . $unique_code . '.png';
		$upload_path       = $upload_dir['path'] . '/wallet-qr-' . $unique_code . '.png';
		// Generates QR Code and Stores it in directory given.
		QRcode::png( $wallet_topup_link, $upload_path );
		$wallet_qr_code = update_user_meta( $user_id, 'wallet_qr_code_image', $upload_url );
		if ( $wallet_qr_code ) {
			show_message_on_qrcode_generation( esc_html__( 'QR Code is generated successfully.', 'woocommerce-wallet-system' ), 'woocommerce-message' );
		} else {
			show_message_on_qrcode_generation( esc_html__( 'QR Code is not generated.', 'woocommerce-wallet-system' ), 'woocommerce-error' );
		}
	}
}

/**
 * Show message on qrcode generation.
 *
 * @param string $wpg_message message.
 * @param string $type message type.
 * @return void
 */
function show_message_on_qrcode_generation( $wpg_message, $type = 'error' ) {
	$wpg_notice = '<div class="woocommerce"><p class="' . esc_attr( $type ) . '">' . $wpg_message . '</p>	</div>';
	echo wp_kses_post( $wpg_notice );
}

?>

<!-- This file should primarily consist of HTML with a little bit of PHP. -->

<?php
/**
 * Get the unique qr code.
 *
 * @param  string $str           qrcode whole string.
 * @param  string $starting_word starting_word.
 * @param  string $ending_word   ending_word.
 * @return string
 */
function string_between_two_string( $str, $starting_word, $ending_word ) {
	$arr = explode( $starting_word, $str );
	if ( isset( $arr[1] ) ) {
		$arr = explode( $ending_word, $arr[1] );
		return $arr[0];
	}
	return '';
}
$start         = 'qr-';
$end           = '.png';
$upload_dir     = wp_upload_dir();
$wallet_qr_code = get_user_meta( $user_id, 'wallet_qr_code_image', true );
$qrcode         = string_between_two_string( $wallet_qr_code, $start, $end );
$image_path     = $upload_dir['basedir'];
$wp_content_url = content_url() . '/uploads';
$wallet_page_id = get_option( 'mwb_wws_wallet_top_page_id' );
$page_url       = get_permalink( $wallet_page_id );
if ( get_option( 'permalink_structure' ) ) {
	if ( substr( $page_url, -1 ) == '/' ) {
		$qr_code_url = $page_url . 'mwb-qrcode-image/' . $qrcode . '/';
	} else {
		$qr_code_url = $page_url . '/mwb-qrcode-image/' . $qrcode;
	}
} else {
	$qr_code_url = add_query_arg( 'mwb-qrcode-image', $qrcode, $page_url );
}
if ( $wallet_qr_code && file_exists( $image_path . $wallet_qr_code ) ) {
	?>
<div class="mwb-wallet-qr-container">
	<div class="item">
		<img class="mwb_qbg_qr_code_img" src="<?php echo $wp_content_url . $wallet_qr_code; ?>" >
	</div>
	<div class="item item-copycode">
		<input type="hidden" value="<?php echo $qr_code_url; ?>" id="copyQrCodeUrl">
		<button id="copyQRCode"><span class="tooltiptext" id="myTooltip"><?php esc_html_e( 'Copy to clipboard', 'woocommerce-wallet-system' ); ?></span><?php esc_html_e( 'Copy QR Code', 'woocommerce-wallet-system' ); ?></button>
	</div>
</div>
<?php } else { ?>
<form  action="" method="post" > 
	<p class="mwb-wallet-field-container form-row">
		<input type="submit" class="mwb-btn__filled button" name="mwb_generate_qr_code" data-user-id="<?php echo esc_attr( $user_id ); ?>" value="<?php esc_attr_e( 'Generate QR Code', 'woocommerce-wallet-system' ); ?>" >
	</p>
	<p class="mwb-wallet-field-container form-row"><?php esc_html_e( 'Generate QR code for recharging wallet through scanning QR code.', 'woocommerce-wallet-system' ); ?></p>
</form>
	<?php
}
?>
