<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://makewebbetter.com/
 * @since             1.0.0
 * @package           Woocommerce_Wallet_System
 *
 * @wordpress-plugin
 * Plugin Name:       WooCommerce Wallet System
 * Plugin URI:        https://wpswings.com/product/wallet-system-woocommerce-Pro/?utm_source=wpswings-wallet-site&utm_medium=wallet-pro-backend&utm_campaign=visit-plugin-site
 * Description:       WooCommerce Wallet System is an addon to Wallet System For WooCommerce plugin that facilitates WooCommerce store owners to provide e-wallet functionalities.
 * Version:           1.0.4
 * Author:            WP Swings
 * Author URI:        https://wpswings.com/?utm_source=wpswings-official&utm_medium=wallet-pro-backend&utm_campaign=official
 * Text Domain:       woocommerce-wallet-system
 * Domain Path:       /languages
 *
 * WC Requires at least: 4.6
 * WC tested up to: 6.1.0
 * WP Requires at least: 5.1.0
 * WP tested up to: 5.8.3
 * Requires PHP: 7.2 or Higher
 *
 * License:           WP Swings License
 * License URI:       https://wpswings.com/license-agreement.txt
 */

// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) {
	die;
}

$active_plugins = (array) get_option( 'active_plugins', array() );
if ( is_multisite() ) {
	$active_plugins = array_merge( $active_plugins, get_site_option( 'active_sitewide_plugins', array() ) );
}
$activated = true;
if ( ! ( array_key_exists( 'wallet-system-for-woocommerce/wallet-system-for-woocommerce.php', $active_plugins ) || in_array( 'wallet-system-for-woocommerce/wallet-system-for-woocommerce.php', $active_plugins ) ) ) {
	$activated = false;
}

if ( $activated ) {
	/**
	 * Define plugin constants.
	 *
	 * @since             1.0.0
	 */
	function define_woocommerce_wallet_system_constants() {

		woocommerce_wallet_system_constants( 'WOOCOMMERCE_WALLET_SYSTEM_VERSION', '1.0.4' );
		woocommerce_wallet_system_constants( 'WOOCOMMERCE_WALLET_SYSTEM_DIR_PATH', plugin_dir_path( __FILE__ ) );
		woocommerce_wallet_system_constants( 'WOOCOMMERCE_WALLET_SYSTEM_DIR_URL', plugin_dir_url( __FILE__ ) );
		woocommerce_wallet_system_constants( 'WOOCOMMERCE_WALLET_SYSTEM_LICENSE_SERVER_URL', 'https://wpswings.com' );
		woocommerce_wallet_system_constants( 'WOOCOMMERCE_WALLET_SYSTEM_ITEM_REFERENCE', 'WooCommerce Wallet System' );
	}

	/**
	 * Define mwb-site update feature.
	 *
	 * @since 1.0.0
	 */
	function auto_update_woocommerce_wallet_system() {
		$mwb_wws_license_key = get_option( 'mwb_wws_lic_key', '' );
		if ( ! defined( 'WOOCOMMERCE_WALLET_SYSTEM_SPECIAL_SECRET_KEY' ) ) {
			define( 'WOOCOMMERCE_WALLET_SYSTEM_SPECIAL_SECRET_KEY', '59f32ad2f20102.74284991' );
		}
		woocommerce_wallet_system_constants( 'WOOCOMMERCE_WALLET_SYSTEM_BASE_FILE', __FILE__ );
		woocommerce_wallet_system_constants( 'WOOCOMMERCE_WALLET_SYSTEM_LICENSE_KEY', $mwb_wws_license_key );
		include_once 'class-mwb-woocommerce-wallet-system-update.php';
	}

	/**
	 * Callable function for defining plugin constants.
	 *
	 * @param   String $key    Key for contant.
	 * @param   String $value   value for contant.
	 * @since             1.0.0
	 */
	function woocommerce_wallet_system_constants( $key, $value ) {

		if ( ! defined( $key ) ) {

			define( $key, $value );
		}
	}

	/**
	 * The code that runs during plugin activation.
	 * This action is documented in includes/class-woocommerce-wallet-system-activator.php
	 *
	 * @param boolean $network_wide networkwide activate.
	 * @return void
	 */
	function activate_woocommerce_wallet_system( $network_wide ) {
		require_once plugin_dir_path( __FILE__ ) . 'includes/class-woocommerce-wallet-system-activator.php';
		Woocommerce_Wallet_System_Activator::woocommerce_wallet_system_activate( $network_wide );
		$mwb_wws_active_plugin = get_option( 'mwb_all_plugins_active', false );
		if ( is_array( $mwb_wws_active_plugin ) && ! empty( $mwb_wws_active_plugin ) ) {
			$mwb_wws_active_plugin['woocommerce-wallet-system'] = array(
				'plugin_name' => __( 'WooCommerce Wallet System', 'woocommerce-wallet-system' ),
				'active' => '1',
			);
		} else {
			$mwb_wws_active_plugin = array();
			$mwb_wws_active_plugin['woocommerce-wallet-system'] = array(
				'plugin_name' => __( 'WooCommerce Wallet System', 'woocommerce-wallet-system' ),
				'active' => '1',
			);
		}
		update_option( 'mwb_all_plugins_active', $mwb_wws_active_plugin );

		if ( ! wp_next_scheduled( 'mwb_wws_check_license_daily' ) ) {
			wp_schedule_event( time(), 'daily', 'mwb_wws_check_license_daily' );
		}
	}

	/**
	 * The code that runs during plugin deactivation.
	 * This action is documented in includes/class-woocommerce-wallet-system-deactivator.php
	 */
	function deactivate_woocommerce_wallet_system() {
		require_once plugin_dir_path( __FILE__ ) . 'includes/class-woocommerce-wallet-system-deactivator.php';
		Woocommerce_Wallet_System_Deactivator::woocommerce_wallet_system_deactivate();
		$mwb_wws_deactive_plugin = get_option( 'mwb_all_plugins_active', false );
		if ( is_array( $mwb_wws_deactive_plugin ) && ! empty( $mwb_wws_deactive_plugin ) ) {
			foreach ( $mwb_wws_deactive_plugin as $mwb_wws_deactive_key => $mwb_wws_deactive ) {
				if ( 'woocommerce-wallet-system' === $mwb_wws_deactive_key ) {
					$mwb_wws_deactive_plugin[ $mwb_wws_deactive_key ]['active'] = '0';
				}
			}
		}
		update_option( 'mwb_all_plugins_active', $mwb_wws_deactive_plugin );
	}

	register_activation_hook( __FILE__, 'activate_woocommerce_wallet_system' );
	register_deactivation_hook( __FILE__, 'deactivate_woocommerce_wallet_system' );

	// Upgrade notice.
	add_action( 'after_plugin_row_' . plugin_basename( __FILE__ ), 'mwb_wws_upgrade_notice', 0, 3 );

	/**
	 Displays notice to upgrade to membership pro.

	 @param string $plugin_file Path to the plugin file relative to the plugins directory.
	 @param array  $plugin_data An array of plugin data.
	 @param string $status Status filter currently applied to the plugin list.
	 */
	function mwb_wws_upgrade_notice( $plugin_file, $plugin_data, $status ) {

		?>

<tr class="plugin-update-tr active notice-warning notice-alt">
	<td colspan="4" class="plugin-update colspanchange">
		<div class="notice notice-success inline update-message notice-alt">
			<div class='wps-notice-title wps-notice-section'>
				<p><strong>IMPORTANT NOTICE:</strong></p>
			</div>
			<div class='wps-notice-content wps-notice-section'>
				<p>From this update <strong>Version 1.0.4</strong> onwards, the plugin and its support will be handled by <strong>WP Swings</strong>.</p><p><strong>WP Swings</strong> is just our improvised and rebranded version with all quality solutions and help being the same, so no worries at your end.
				Please connect with us for all setup, support, and update related queries without hesitation.</p>
			</div>
		</div>
	</td>
</tr>
<style>
	.wps-notice-section > p:before {
		content: none;
	}
</style>

		<?php

	}//end mwb_wws_upgrade_notice()

	/**
	 * The core plugin class that is used to define internationalization,
	 * admin-specific hooks, and public-facing site hooks.
	 */
	require plugin_dir_path( __FILE__ ) . 'includes/class-woocommerce-wallet-system.php';

	/**
	 * Creating table whenever a new blog is created
	 *
	 * @param object $new_site New site object.
	 * @return void
	 */
	function mwb_wws_on_create_blog( $new_site ) {
		if ( ! function_exists( 'is_plugin_active_for_network' ) ) {
			require_once ABSPATH . '/wp-admin/includes/plugin.php';
		}
		if ( is_plugin_active_for_network( 'woocommerce-wallet-system/woocommerce-wallet-system.php' ) ) {
			$license_key   = get_option( 'mwb_wws_lic_key' );
			$license_valid = get_option( 'mwb_wws_pro_valid_license' );
			$blog_id       = $new_site->blog_id;
			switch_to_blog( $blog_id );
			update_option( 'mwb_wws_lic_key', $license_key );
			update_option( 'mwb_wws_pro_valid_license', $license_valid );
			require_once plugin_dir_path( __FILE__ ) . 'includes/class-woocommerce-wallet-system-activator.php';
			Woocommerce_Wallet_System_Activator::mwb_wws_create_wallet_page();
			Woocommerce_Wallet_System_Activator::mwb_wws_activated_timestamp();
			restore_current_blog();
		}
	}
	add_action( 'wp_initialize_site', 'mwb_wws_on_create_blog', 900 );

	/**
	 * Begins execution of the plugin.
	 *
	 * Since everything within the plugin is registered via hooks,
	 * then kicking off the plugin from this point in the file does
	 * not affect the page life cycle.
	 *
	 * @since    1.0.0
	 */
	function run_woocommerce_wallet_system() {
		define_woocommerce_wallet_system_constants();
		auto_update_woocommerce_wallet_system();
		$wws_plugin_standard = new Woocommerce_Wallet_System();
		$wws_plugin_standard->wws_run();
		$GLOBALS['wws_mwb_wws_obj'] = $wws_plugin_standard;

	}
	run_woocommerce_wallet_system();

	// Add settings link on plugin page.
	add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'woocommerce_wallet_system_settings_link' );

	/**
	 * Settings link.
	 *
	 * @since    1.0.0
	 * @param   Array $links    Settings link array.
	 */
	function woocommerce_wallet_system_settings_link( $links ) {

		$my_link = array(
			'<a href="' . admin_url( 'admin.php?page=wallet_system_for_woocommerce_menu' ) . '">' . __( 'Settings', 'woocommerce-wallet-system' ) . '</a>',
		);
		return array_merge( $my_link, $links );
	}

	/**
	 * Adding custom setting links at the plugin activation list.
	 *
	 * @param array  $links_array array containing the links to plugin.
	 * @param string $plugin_file_name plugin file name.
	 * @return array
	 */
	function woocommerce_wallet_system_custom_settings_at_plugin_tab( $links_array, $plugin_file_name ) {
		if ( strpos( $plugin_file_name, basename( __FILE__ ) ) ) {
			$links_array[] = '<a href="https://demo.wpswings.com/wallet-system-for-woocommerce-pro/?utm_source=wpswings-wallet-demo&utm_medium=wallet-pro-backend&utm_campaign=demo" target="_blank"><img src="' . esc_html( WOOCOMMERCE_WALLET_SYSTEM_DIR_URL ) . 'admin/image/Demo.svg" class="mwb-info-img" alt="Demo image">' . __( 'Demo', 'woocommerce-wallet-system' ) . '</a>';
			$links_array[] = '<a href="https://docs.wpswings.com/wallet-system-for-woocommerce-pro/?utm_source=wpswings-wallet-doc&utm_medium=wallet-pro-backend&utm_campaign=doc" target="_blank"><img src="' . esc_html( WOOCOMMERCE_WALLET_SYSTEM_DIR_URL ) . 'admin/image/Documentation.svg" class="mwb-info-img" alt="documentation image">' . __( 'Documentation', 'woocommerce-wallet-system' ) . '</a>';
			$links_array[] = '<a href="https://wpswings.com/submit-query/?utm_source=wpswings-wallet-query&utm_medium=wallet-pro-backend&utm_campaign=support" target="_blank"><img src="' . esc_html( WOOCOMMERCE_WALLET_SYSTEM_DIR_URL ) . 'admin/image/Support.svg" class="mwb-info-img" alt="support image">' . __( 'Support', 'woocommerce-wallet-system' ) . '</a>';
		}
		return $links_array;
	}
	add_filter( 'plugin_row_meta', 'woocommerce_wallet_system_custom_settings_at_plugin_tab', 10, 2 );
} else {
	// To deactivate plugin if woocommerce is not installed.
	add_action( 'admin_init', 'mwb_wws_plugin_deactivate' );

	/**
	 * Call Admin notices
	 *
	 * @name mwb_wws_plugin_deactivate()
	 */
	function mwb_wws_plugin_deactivate() {
		deactivate_plugins( plugin_basename( __FILE__ ), true );
		unset( $_GET['activate'] );
		add_action( 'admin_notices', 'mwb_wws_plugin_error_notice', 10 );
	}

	/**
	 * Show warning message if Wallet System For WooCommerce is not install
	 *
	 * @name mwb_wws_plugin_error_notice()
	 */
	function mwb_wws_plugin_error_notice() {
		?>
		<div class="error notice is-dismissible">
			<p>
				<?php esc_html_e( 'Wallet System For WooCommerce is not activated, Please activate Wallet System For WooCommerce first to install WooCommerce Wallet System.', 'woocommerce-wallet-system' ); ?>
			</p>
		</div>
		<?php
	}
}
